@@ -24,10 +24,10 @@ SEXP rowCounts(SEXP x, SEXP dim, SEXP rows, SEXP cols, SEXP value, SEXP what, SE
 
   /* Argument 'value': */
   if (length(value) != 1)
-    error("Argument 'value' must be a single value.");
+    error("Argument 'value' must be a single value");
 
   if (!isNumeric(value))
-    error("Argument 'value' must be a numeric or a logical value.");
+    error("Argument 'value' must be a numeric or a logical value");
 
   /* Argument 'what': */
   what2 = asInteger(what);
@@ -60,9 +60,9 @@ SEXP rowCounts(SEXP x, SEXP dim, SEXP rows, SEXP cols, SEXP value, SEXP what, SE
   }
   
   /* Argument 'useNames': */ 
-  usenames = asLogical(useNames);
+  usenames = asLogicalNoNA(useNames, "useNames");
   
-  if (usenames != NA_LOGICAL && usenames) {
+  if (usenames) {
     SEXP dimnames = getAttrib(x, R_DimNamesSymbol);
     if (dimnames != R_NilValue) {
       SEXP namesVec = VECTOR_ELT(dimnames, 0);
