@@ -1,14 +1,13 @@
 library("matrixStats")
 
-rowCumprods_R <- function(x, ..., useNames = NA) {
+rowCumprods_R <- function(x, ..., useNames = TRUE) {
   suppressWarnings({
     y <- t(apply(x, MARGIN = 1L, FUN = cumprod))
   })
   
   # Preserve dimnames attribute?
   dim(y) <- dim(x)
-  dimnames <- dimnames(x)
-  if (isTRUE(useNames) && !is.null(dimnames)) dimnames(y) <- dimnames  
+  dimnames(y) <- if (useNames) dimnames(x) else NULL
   
   y
 }
@@ -21,23 +20,23 @@ for (mode in c("logical", "integer", "double")) {
   for (add_na in c(FALSE, TRUE)) {
     cat("add_na = ", add_na, "\n", sep = "")
 
-    x <- matrix(1:100, nrow = 20, ncol = 5)
+    x <- matrix(1:50, nrow = 10L, ncol = 5L)
     if (add_na) {
-      x[13:17, c(2, 4)] <- NA_real_
+      x[3:7, c(2, 4)] <- NA_real_
     }
     cat("mode: ", mode, "\n", sep = "")
     storage.mode(x) <- mode
     str(x)
     
     # To check dimnames attribute
-    dimnames <- list(letters[1:20], LETTERS[1:5])
+    dimnames <- list(letters[1:10], LETTERS[1:5])
     
     # Test with and without dimnames on x
     for (setDimnames in c(TRUE, FALSE)) {
       if (setDimnames) dimnames(x) <- dimnames
       else dimnames(x) <- NULL    
       # Check names attribute
-      for (useNames in c(NA, TRUE, FALSE)) {
+      for (useNames in c(TRUE, FALSE)) {
         # Row/column ranges
         r0 <- rowCumprods_R(x, useNames = useNames)
         r1 <- rowCumprods(x, useNames = useNames)
@@ -55,7 +54,7 @@ for (mode in c("logical", "integer", "double")) {
 # All NAs
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 for (mode in c("logical", "integer", "double")) {
-  x <- matrix(NA_real_, nrow = 20, ncol = 5)
+  x <- matrix(NA_real_, nrow = 10L, ncol = 5L)
   cat("mode: ", mode, "\n", sep = "")
   storage.mode(x) <- mode
   str(x)
@@ -65,7 +64,7 @@ for (mode in c("logical", "integer", "double")) {
     if (setDimnames) dimnames(x) <- dimnames
     else dimnames(x) <- NULL    
     # Check names attribute
-    for (useNames in c(NA, TRUE, FALSE)) {
+    for (useNames in c(TRUE, FALSE)) {
       # Row/column ranges
       r0 <- rowCumprods_R(x, useNames = useNames)
       r1 <- rowCumprods(x, useNames = useNames)
@@ -82,7 +81,7 @@ for (mode in c("logical", "integer", "double")) {
 # A 1x1 matrix
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 for (mode in c("logical", "integer", "double")) {
-  x <- matrix(0, nrow = 1, ncol = 1)
+  x <- matrix(0, nrow = 1L, ncol = 1L)
   cat("mode: ", mode, "\n", sep = "")
   storage.mode(x) <- mode
   str(x)
@@ -93,7 +92,7 @@ for (mode in c("logical", "integer", "double")) {
     if (setDimnames) dimnames(x) <- dimnames
     else dimnames(x) <- NULL    
     # Check names attribute
-    for (useNames in c(NA, TRUE, FALSE)) {
+    for (useNames in c(TRUE, FALSE)) {
       # Row/column ranges
       r0 <- rowCumprods_R(x, useNames = useNames)
       r1 <- rowCumprods(x, useNames = useNames)
@@ -109,7 +108,7 @@ for (mode in c("logical", "integer", "double")) {
 # BUG FIX TEST: Assert zeros don't trump NAs in integer matrices
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 for (mode in c("logical", "integer", "double")) {
-  x <- matrix(NA_real_, nrow = 3, ncol = 2)
+  x <- matrix(NA_real_, nrow = 3L, ncol = 2L)
   x[1, 2] <- 0
   x[2, 2] <- 1
   x[3, 1] <- 0
@@ -123,7 +122,7 @@ for (mode in c("logical", "integer", "double")) {
     if (setDimnames) dimnames(x) <- dimnames
     else dimnames(x) <- NULL    
     # Check names attribute
-    for (useNames in c(NA, TRUE, FALSE)) {
+    for (useNames in c(TRUE, FALSE)) {
       # Row/column ranges
       r0 <- rowCumprods_R(x, useNames = useNames)
       r1 <- rowCumprods(x, useNames = useNames)
@@ -164,7 +163,7 @@ for (mode in c("logical", "integer", "double")) {
     if (setDimnames) colnames(x) <- colnames
     else dimnames(x) <- NULL
     # Check names attribute
-    for (useNames in c(NA, TRUE, FALSE)) {
+    for (useNames in c(TRUE, FALSE)) {
       r0 <- rowCumprods_R(x, useNames = useNames)
       r1 <- rowCumprods(x, useNames = useNames)
       r2 <- t(rowCumprods(t(x), useNames = useNames))
@@ -183,7 +182,7 @@ for (mode in c("logical", "integer", "double")) {
     if (setDimnames) rownames(x) <- rownames
     else dimnames(x) <- NULL
     # Check names attribute
-    for (useNames in c(NA, TRUE, FALSE)) {
+    for (useNames in c(TRUE, FALSE)) {
       r0 <- rowCumprods_R(x, useNames = useNames)
       r1 <- rowCumprods(x, useNames = useNames)
       r2 <- t(rowCumprods(t(x), useNames = useNames))
